angular.module('gaugesScreen', [])
.controller('GaugesScreenController', function($scope, $window) {
  var units = {uiUnitConsumptionRate: "metric",
  uiUnitDate: "ger",
  uiUnitEnergy: "metric",
  uiUnitLength: "metric",
  uiUnitPower: "hp",
  uiUnitPressure: "bar",
  uiUnitTemperature: "c",
  uiUnitTorque: "metric",
  uiUnitVolume: "l",
  uiUnitWeight: "kg"};

  $scope.data = {}
  // overwriting plain javascript function so we can access from within the controller
    $window.setup = (data) => {
      if(!ready){
        console.log("calling setup while svg not fully loaded");
        setTimeout(function(){ $window.setup(data) }, 100);
        return;
      }
      console.log("setup",data);
      for(let dk in data){
        if(typeof dk == "string" && dk.startsWith("uiUnit")){
          units[dk] = data[dk];
        }
      }
      vueEventBus.emit('SettingsChanged', {values:units});

      cellsDescription = data.cells;

	
	if (units.uiUnitLength === "metric") {
		$scope.data.speedUnit = "km/h";
	}
	else {
		$scope.data.speedUnit = "mph";
	}
	
  }

  function getValueFromPath(data,path){
	let splittedPath = path.split('.');
	let dataStack = data;
	for( let p in splittedPath){
	  if(! (splittedPath[p] in dataStack)){
		console.log("path undefined ",splittedPath[p] , "complete=", path);
		return 0;
	  }
	  dataStack = dataStack[splittedPath[p]]
	}
	return dataStack
  }

  function getUiUnitFromPath(data, cellsDescription, currentCell){
	let cellName = currentCell.indexOf('.')> -1? currentCell.split('.')[0]:currentCell;
	let path = currentCell.indexOf('.')> -1? cellsDescription[cellName][currentCell.split('.')[1]]:cellsDescription[currentCell].path;
	switch(cellsDescription[cellName].unit){
	  case "":
	  case undefined: //because CEF...
		return { val: getValueFromPath(data,path), unit: ''}
	  case "bool":
		let v = getValueFromPath(data,path);
		return { val: (v===true||v>0.5)?"TRUE":"FALSE", unit: ''}
	  case "gear":
		return { val: gearToStr(getValueFromPath(data,path)), unit: ''}
	  case "light":
		switch( Math.round(getValueFromPath(data,path))){
		  case 0:
			return { val: "OFF", unit: ''}
		  case 1:
			return { val: "LOW", unit: ''}
		  case 2:
			return { val: "HIGH", unit: ''}
		  default:
			return { val: "???", unit: ''}
		}
	  case "pressureFromPsi":
		return UiUnits["pressure"](getValueFromPath(data,path)*6.89476)
	  case "consumptionRate":
		return UiUnits["consumptionRate"](getValueFromPath(data,path)* 1e-5)
	  default:
		return UiUnits[cellsDescription[cellName].unit](getValueFromPath(data,path))
	}
  }

	$window.updateData = (data) => {
			$scope.$evalAsync(function() {

			//gear selector
			if (data.electrics.gear === -1) {
				$scope.data.gear = "R";
			}
			else if (data.electrics.gear === 0) {
				$scope.data.gear = "N";
			}
			else {
				$scope.data.gear = data.electrics.gear;
			}



			// checking gauge cluster units
			if (units.uiUnitLength === "metric") {
				$scope.data.TopRightVal = (data.electrics.wheelspeed * 3.6).toFixed(0);
				$scope.data.TopRightUnit = "km/h";
				$scope.data.TopRightText = "SPEED";
			}
			else {
				$scope.data.TopRightVal = (data.electrics.wheelspeed * 2.23694).toFixed(0);
				$scope.data.TopRightUnit = "mph";
				$scope.data.TopRightText = "SPEED";
			}
			
			if (units.uiUnitTemperature === "c") {
				$scope.data.BottomRightVal = data.electrics.watertemp.toFixed(0);
				$scope.data.BottomRightUnit = "C";
				$scope.data.BottomRightText = "WATER";
				$scope.data.BottomLeftVal = data.electrics.oiltemp.toFixed(0);
				$scope.data.BottomLeftUnit = "C";
				$scope.data.BottomLeftText = "OIL";
			}
			else {
				$scope.data.BottomRightVal = (data.electrics.watertemp * 1.8 + 32).toFixed(0);
				$scope.data.BottomRightUnit = "F";
				$scope.data.BottomRightText = "WATER";
				$scope.data.BottomLeftVal = (data.electrics.oiltemp * 1.8 + 32).toFixed(0);
				$scope.data.BottomLeftUnit = "C";
				$scope.data.BottomLeftText = "OIL";
			}
			
			if (units.uiUnitVolume === "l") {
				$scope.data.TopLeftVal = Math.floor(data.electrics.fuelVolume*10) /10;
				$scope.data.TopLeftUnit= "L";
				$scope.data.TopLeftText= "FUEL";
			}
			else {
				$scope.data.TopLeftVal = Math.floor(data.electrics.fuelVolume / 3.785 *10) /10;
				$scope.data.TopLeftUnit= "Gal";
				$scope.data.TopLeftText= "FUEL";
			}
			
			
			//sweeping RPM gauge
			RPMNumber = Math.round(data.electrics.rpmTacho / 100)
			for (i = 1; i < 71; i++) {
				if (i <= RPMNumber) {
					document.getElementById("RPM" + i).style.display = "";
				} 
				else {
					document.getElementById("RPM" + i).style.display = "none";	
				} 
			} 
		})
	}
}
);    